#ifndef NT2_INCLUDE_CONSTANTS_LOG_10_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_LOG_10_HPP_INCLUDED

#include <nt2/exponential/include/constants/log_10.hpp>

#endif
